use archive::WebsiteArchive;
use based::get_pg;
use rocket::routes;

mod archive;
mod pages;
mod favicon;

#[rocket::launch]
async fn launch() -> _ {
    env_logger::init();

    let pg = get_pg!();
    sqlx::migrate!("./migrations").run(pg).await.unwrap();

    let arc = WebsiteArchive::new("./websites");

    favicon::download_favicons_for_sites(arc.domains()).await;

    rocket::build()
        .mount(
            "/",
            routes![
                pages::index,
                pages::render_website,
                pages::domain_info_route,
                pages::favicon_route
            ],
        )
        .manage(arc)
}
